from sefaria_fortune_gen import AvailableTextReference, TextContent
from re import sub
import sys

def snake_case(s):
    # Replace hyphens with spaces, then apply regular expression substitutions for title case conversion
    # and add an underscore between words, finally convert the result to lowercase
    return '_'.join(
        sub('([A-Z][a-z]+)', r' \1',
        sub('([A-Z]+)', r' \1',
        s.replace('-', ' ').replace('.', ''))).split()).lower()

if len(sys.argv) < 2:
    print("Please specify a starting section reference, like 'Pirkei Avot 1'.")
    sys.exit(1)

text = " ".join(sys.argv[1:])
atr = AvailableTextReference(text)
print(f"Creating fortunedb for '{atr.index_title}' ('{atr.primary_category}').")
if atr.prev is not None:
    print(f"WARN: Starting at '{atr.title}', which doesn't appear to begin '{atr.index_title}'.")
hebrew_version = atr.versions['hebrew'][0]
print(f"Using Hebrew from '{hebrew_version}'.")
english_version = atr.versions['english'][0]
print(f"Using English from '{english_version}'.")

filename = "" + snake_case(atr.primary_category) + "-" + \
        snake_case(atr.index_title) + "-" + \
        snake_case(hebrew_version) + "-" + \
        snake_case(english_version) + ".fortunedb"

print(f"Output filename '{filename}'.")

with open(filename, "w") as f:
    section_atr = atr

    while section_atr is not None:
        print(f"Handling {section_atr.title} ({section_atr.subsections} subs)")
        for subsection_number in range(1, section_atr.subsections + 1):
            subsection_title = "" + section_atr.title + "." + str(subsection_number)
            subsection_atr = None
            try:
                subsection_atr = AvailableTextReference(subsection_title)
            except Exception as e:
                print(f"WARN: Skipped {subsection_title}: {e}")
                continue
            hebrew_tc = TextContent(subsection_title, 'hebrew', hebrew_version)
            english_tc = TextContent(subsection_title, 'english', english_version)
            hebrew_text = hebrew_tc.text.replace("<br>", "\n")
            english_text = english_tc.text.replace("<br>", "\n")
            f.write(hebrew_text)
            f.write("\n")
            f.write(english_text)
            f.write("\n")
            f.write(f"  - {subsection_title}\n%\n")
        if section_atr.next is not None:
            section_atr = AvailableTextReference(section_atr.next)
        else:
            section_atr = None

